ncem
===========================

|PyPI| |Python Version| |License| |Read the Docs| |Build| |pre-commit| |Black|

.. |PyPI| image:: https://img.shields.io/pypi/v/ncem.svg
   :target: https://pypi.org/project/ncem/
   :alt: PyPI
.. |Python Version| image:: https://img.shields.io/pypi/pyversions/ncem
   :target: https://pypi.org/project/ncem
   :alt: Python Version
.. |License| image:: https://img.shields.io/github/license/theislab/ncem
   :target: https://opensource.org/licenses/BSD-3-Clause
   :alt: License
.. |Read the Docs| image:: https://img.shields.io/readthedocs/ncem/latest.svg?label=Read%20the%20Docs
   :target: https://ncem.readthedocs.io/
   :alt: Read the documentation at https://ncem.readthedocs.io/
.. |Build| image:: https://github.com/theislab/ncem/workflows/Build%20ncem%20Package/badge.svg
   :target: https://github.com/theislab/ncem/actions?workflow=Package
   :alt: Build Package Status
.. |Tests| image:: https://github.com/theislab/ncem/workflows/Run%20ncem%20Tests/badge.svg
   :target: https://github.com/theislab/ncem/actions?workflow=Tests
   :alt: Run Tests Status
.. |Codecov| image:: https://codecov.io/gh/theislab/ncem/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/theislab/ncem
   :alt: Codecov
.. |pre-commit| image:: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
   :target: https://github.com/pre-commit/pre-commit
   :alt: pre-commit
.. |Black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Black

.. image:: https://raw.githubusercontent.com/theislab/ncem/main/docs/_static/img/concept.png
   :target: https://raw.githubusercontent.com/theislab/ncem/main/docs/_static/img/concept.png
   :align: center
   :alt: ncem concept
   :width: 1000px


Features
--------
ncem_ is a model repository in a single python package for the manuscript *Fischer, D. S., Schaar, A. C. and Theis, F. Learning cell communication from spatial
graphs of cells. 2021.* (preprint_)


Installation
------------

You can install *ncem* via pip_ from PyPI_:

.. code:: console

   $ pip install ncem


Credits
-------

This package was created with cookietemple_ using Cookiecutter_ based on Hypermodern_Python_Cookiecutter_.

.. _ncem: https://ncem.readthedocs.io
.. _cookietemple: https://cookietemple.com
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _PyPI: https://pypi.org/
.. _Hypermodern_Python_Cookiecutter: https://github.com/cjolowicz/cookiecutter-hypermodern-python
.. _pip: https://pip.pypa.io/
.. _Usage: https://ncem.readthedocs.io/en/latest/usage.html
.. _preprint: https://www.biorxiv.org/content/10.1101/2021.07.11.451750v1
